# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# We need to patch the test suite if we have an old version of Test::More
%global old_test_more %(perl -MTest::More -e 'print (($Test::More::VERSION < 0.88) ? 1 : 0);' 2>/dev/null || echo 0)
%global older_test_more %(perl -MTest::More -e 'print (($Test::More::VERSION < 0.82) ? 1 : 0);' 2>/dev/null || echo 0)

# Need Perl 5.10.x or later for Test::More 0.86, needed by Test::FailWarnings
%if 0%{?fedora} < 9 && 0%{?rhel} < 6
%global no_test_failwarnings 1
%else
%global no_test_failwarnings 0
%endif

Name:		perl-Data-Section
Version:	0.200006
Release:	7.%{__distinit}%{__distvers}
Summary:	Read multiple hunks of data out of your DATA section
License:	GPL+ or Artistic
Group:		Development/Libraries
URL:		http://search.cpan.org/dist/Data-Section/
Source0:	http://search.cpan.org/CPAN/authors/id/R/RJ/RJBS/Data-Section-%{version}.tar.gz
Patch1:		Data-Section-0.200006-old-Test::More.patch
Patch2:		Data-Section-0.200003-no-T::FW.patch
Patch3:		Data-Section-0.200006-note.patch
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl
%if 0%{?fedora} > 20 || 0%{?rhel} > 7
BuildRequires:	perl-generators
%endif
BuildRequires:	perl(ExtUtils::MakeMaker) >= 6.30
# Module Runtime
BuildRequires:	perl(Encode)
BuildRequires:	perl(MRO::Compat) >= 0.09
BuildRequires:	perl(strict)
BuildRequires:	perl(Sub::Exporter) >= 0.979
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(base)
BuildRequires:	perl(lib)
%if ! %{no_test_failwarnings}
BuildRequires:	perl(Test::FailWarnings)
%endif
BuildRequires:	perl(Test::More)
BuildRequires:	perl(utf8)
# Extra Tests
BuildRequires:	perl(Test::Pod) >= 1.41
# Dependencies
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))

%description
Data::Section provides an easy way to access multiple named chunks of
line-oriented data in your module's DATA section. It was written to allow
modules to store their own templates, but probably has other uses.

%prep
%setup -q -n Data-Section-%{version}

# Hack for old Test::More versions
%if %{old_test_more}
%patch1
%endif
%if %{no_test_failwarnings}
%patch2
%endif
%if %{older_test_more}
%patch3
%endif

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} %{buildroot}

%check
make test
make test TEST_FILES="$(echo $(find xt/ -name '*.t'))"

%clean
rm -rf %{buildroot}

%files
%if 0%{?_licensedir:1}
%license LICENSE
%else
%doc LICENSE
%endif
%doc Changes README
%{perl_vendorlib}/Data/
%{_mandir}/man3/Data::Section.3*

%changelog
* Mon Aug 15 2016 Paul Howarth <paul@city-fan.org> - 0.200006-7
- Fix FTBFS when perl is not in the minimal buildroot
- Classify buildreqs by usage
- Simplify find command using -delete

* Thu Sep 11 2014 Paul Howarth <paul@city-fan.org> - 0.200006-3
- Drop support for building with ExtUtils::MakeMaker < 6.30
- Drop %%defattr, redundant since rpm 4.4
- Use %%license where possible

* Mon Mar 10 2014 Paul Howarth <paul@city-fan.org> - 0.200006-1
- Update to 0.200006
  - Skip tests on Win32 pre-5.14 related to line endings; perl munges the data
    before we're able to get at it
- Update patches as needed

* Wed Dec 11 2013 Paul Howarth <paul@city-fan.org> - 0.200005-1
- Update to 0.200005
  - Open DATA handles both :raw and :bytes to avoid content munging on Win32
  - This is not yet a perfect solution for Win32
- Update patches as needed

* Mon Dec  2 2013 Paul Howarth <paul@city-fan.org> - 0.200004-1
- Update to 0.200004
  - Avoid confusion between \n, \x0d\x0a, and Win32
- Update patches as needed

* Mon Nov  4 2013 Paul Howarth <paul@city-fan.org> - 0.200003-1
- Update to 0.200003
  [THIS MIGHT BREAK STUFF]
  - Add an "encoding" parameter to set encoding of data section contents; this
    defaults to UTF-8
- Update patches as needed
- Add patch to support building without Test::FailWarnings if necessary

* Fri Jul 19 2013 Paul Howarth <paul@city-fan.org> - 0.101622-2
- Perl 5.18 rebuild

* Thu Jun 20 2013 Paul Howarth <paul@city-fan.org> - 0.101622-1
- Update to 0.101622
  - Add a link to an Advent article about Data-Section
  - Update bugtracker, repo, etc.
- Run the release tests separately
- BR: perl(File::Find) and perl(File::Temp) for the test suite
- Drop BR: perl(Pod::Coverage::TrustPod), should have gone last time
- Update patches

* Sat Jul  7 2012 Paul Howarth <paul@city-fan.org> - 0.101621-4
- BR: perl(base) and perl(lib)
- Drop BR: perl(Test::Pod::Coverage), not needed for this version

* Wed Mar  7 2012 Paul Howarth <paul@city-fan.org> - 0.101621-3
- Don't need to remove empty directories from buildroot
- Drop compatibility with distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Thu Jun 23 2011 Paul Howarth <paul@city-fan.org> - 0.101621-2
- Rebuild for perl 5.14.1 in Rawhide
- Fix dist tag for CentOS 6 and Scientific Linux

* Sat Apr 30 2011 Paul Howarth <paul@city-fan.org> - 0.101621-1
- Update to 0.101621 (document the \-escaping behavior of sections)
- Update patch for old ExtUtils::MakeMaker and apply it only when needed
- Nobody else likes macros for commands

* Wed Jun 23 2010 Paul Howarth <paul@city-fan.org> - 0.101620-2
- Rebuild for perl 5.12.1 in Rawhide

* Fri Jun 11 2010 Paul Howarth <paul@city-fan.org> - 0.101620-1
- Update to 0.101620 (attempt to work with files with Win32 line endings)
- Update patches

* Tue May 11 2010 Paul Howarth <paul@city-fan.org> - 0.100770-2
- Fix dist tag for RHEL-6 Beta

* Fri Mar 19 2010 Paul Howarth <paul@city-fan.org> - 0.100770-1
- Update to 0.100770
  - __END__ now ends the whole data section; ignore_end may come someday
  - Empty data lines between __DATA__ and first section are ignored
- Update patch for old Test::More versions

* Wed Feb  3 2010 Paul Howarth <paul@city-fan.org> - 0.100270-2
- Enable RELEASE_TESTING
- BR: perl(Pod::Coverage::TrustPod), perl(Test::Pod), perl(Test::Pod::Coverage)

* Thu Jan 28 2010 Paul Howarth <paul@city-fan.org> - 0.100270-1
- Import from Fedora
- Update to 0.100270

* Tue Jan 12 2010 Daniel P. Berrange <berrange@redhat.com> - 0.093410-2
- Fix source URL

* Thu Jan  7 2010 Daniel P. Berrange <berrange@redhat.com> - 0.093410-1
- Update to 0.093410 release

* Mon Dec  7 2009 Stepan Kasal <skasal@redhat.com> - 0.091820-3
- Rebuild against perl 5.10.1

* Sat Jul 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.091820-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed Jul 22 2009 Daniel P. Berrange <berrange@redhat.com> - 0.091820-1
- Update to 0.091820 release

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.005-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Sat Sep 06 2008 Daniel P. Berrange <berrange@redhat.com> - 0.005-2
- Add Test::More BR

* Fri Sep 05 2008 Daniel P. Berrange <berrange@redhat.com> - 0.005-1
- Specfile autogenerated by cpanspec 1.77
